@@ -1,6 +1,6 @@
 /*
 parolottero
-Copyright (C) 2021-2024 Salvo "LtWorf" Tomaselli
+Copyright (C) 2021-2025 Salvo "LtWorf" Tomaselli
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -86,7 +86,49 @@ void BoardManager::init() {
     }
 
     emit playable_changed(true);
+}
 
+void explore_words(QList<unsigned int> used, unsigned int start, unsigned int size, BoardManager* board, QStringList *r, Language* lang) {
+
+    QString prefix;
+    for (auto i = 0; i < used.size(); i++) {
+        prefix += board->get_letter(used[i]);
+    }
+    prefix += board->get_letter(start);
+
+    if (lang->is_word(prefix) && !r->contains(prefix)) {
+        r->append(prefix);
+    }
+    else if (!lang->is_prefix(prefix)) {
+        return;
+    }
+
+    used << start;
+    for (unsigned int i = 0; i < size; i++) {
+        if (i == start)
+            continue;
+        if (used.contains(i))
+            continue;
+        if (!board->are_adjacent(start, i))
+            continue;
+        explore_words(used, i, size, board, r, lang);
+    }
+    used.pop_back();
+}
+
+/**
+ * @brief get_possible_words
+ * @return all the word this board contains
+ */
+QStringList BoardManager::get_possible_words() {
+    QStringList r;
+    QList<unsigned int> used;
+
+    for (unsigned int i = 0; i < this->get_size(); i++) {
+        explore_words(used, i, this->get_size(), this, &r, this->language);
+    }
+
+    return r;
 }
 
 /**
