@@ -1,6 +1,6 @@
 /*
 parolottero
-Copyright (C) 2021-2024 Salvo "LtWorf" Tomaselli
+Copyright (C) 2021-2025 Salvo "LtWorf" Tomaselli
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -25,6 +25,7 @@ author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 #include <QList>
 #include <QString>
 #include <QSet>
+#include <QStringList>
 
 #include "language.h"
 #include "scoreboard.h"
@@ -85,6 +86,7 @@ public slots:
     unsigned int get_total();
     unsigned int get_multiplier(unsigned int cell);
     QString get_letter(unsigned int cell);
+    QStringList get_possible_words();
 
     void set_seed(unsigned int);
     unsigned int get_seed();
